EParticle class

Constructors

EParticle(ERelativePair position, EVector2D movement, double radius, double decreaseRadius)

Properties

decreaseRadius ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
initRadius ↔ double
getter/setter pair
movement ↔ EVector2D
getter/setter pair
position ↔ ERelativePair
getter/setter pair
radius ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
update(double deltaTime, Size size) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited