EGradient class

Constructors

EGradient(List<EColorShift> colorShifts)

Properties

colorShifts ↔ List<EColorShift>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getLinearGradient(Alignment begin, Alignment end) → LinearGradient
getRadialGradient() → RadialGradient
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
update(double deltaTime) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited