ELight class

Inheritance
Implementers

Constructors

ELight(double flickerOn, double flickerOff, ERelative blur, ERelative blurPulseRange, double blurPulseSpeed, {String name = ""})

Properties

blur ↔ ERelative
getter/setter pair
blurPulseRange ↔ ERelative
getter/setter pair
blurPulseSpeed ↔ double
getter/setter pair
currentBlur → double
no setter
flickerOff ↔ double
getter/setter pair
flickerOn ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isDrawable → bool
no setterinherited
isToggled ↔ bool
getter/setter pairinherited
name ↔ String
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateFromScene → bool
no setterinherited

Methods

draw(Canvas canvas, Size size) → void
inherited
drawEffect(Canvas canvas, Size size) → void
inherited
drawLight(Canvas canvas, Size size) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toggle() → void
inherited
toString() → String
A string representation of this object.
inherited
update(double deltaTime, Size size) → void
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited