EVector2D class

Constructors

EVector2D(double x, double y)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x ↔ double
getter/setter pair
y ↔ double
getter/setter pair

Methods

add(EVector2D vct) → void
getAdd(EVector2D vct) → EVector2D
getAngle(EVector2D vct) → double
getLength() → double
getMultiply(double factor) → EVector2D
getOffset() → Offset
getRotate(double alpha) → EVector2D
multiply(double factor) → void
norm() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rotate(double alpha) → void
setLength(double length) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited